@@ -25,7 +25,7 @@ task = projectal.Task.create(project, {
 pprint(task)
 
 print('Getting project with tasks')
-project = projectal.Project.get(project, links='TASK')
+project = projectal.Project.get(project, links=['TASK'])
 # See 'taskList' in response
 pprint(project)
 
