@@ -25,6 +25,7 @@ from datetime import timezone, datetime
 
 import requests
 from packaging import version
+from requests import PreparedRequest
 
 try:
     from simplejson.errors import JSONDecodeError
@@ -254,4 +255,8 @@ def __maybe_fail_status(response, payload):
 
 
 def _build_url(endpoint):
-    return projectal.api_base.rstrip('/') + endpoint
+    req = PreparedRequest()
+    url = projectal.api_base.rstrip('/') + endpoint
+    params = {'alias': projectal.api_alias}
+    req.prepare_url(url, params)
+    return req.url
