@@ -4,13 +4,13 @@ from projectal import api
 
 
 class File(Entity, CompanyLinker, CustomerLinker, FolderLinker, ProjectLinker,
-           StaffLinker, TaskLinker, TaskTemplateLinker, NoteLinker):
+           StaffLinker, TaskLinker, TaskTemplateLinker, NoteLinker, TagLinker):
     """
     Implementation of the [File](https://projectal.com/docs/latest/#tag/File) API.
     """
     _path = 'file'
     _name = 'file'
-    _links = [NoteLinker]
+    _links = [NoteLinker, TagLinker]
     _links_reverse = [CompanyLinker, CustomerLinker, FolderLinker, ProjectLinker,
                       StaffLinker, TaskLinker, TaskTemplateLinker]
 
