@@ -2,14 +2,14 @@ from projectal import api
 from projectal.entity import Entity
 from projectal.linkers import *
 
-class ProjectTemplate(Entity, NoteLinker):
+class ProjectTemplate(Entity, NoteLinker, TagLinker):
     """
     Implementation of the
     [Project Template](https://projectal.com/docs/latest/#tag/Project-Template) API.
     """
     _path = 'template/project'
     _name = 'project_template'
-    _links = [NoteLinker]
+    _links = [NoteLinker, TagLinker]
 
     @classmethod
     def autoschedule(cls, project, mode='ASAP'):
