@@ -7,7 +7,7 @@ class Webhook(Entity):
     Implementation of the [Webhook](https://projectal.com/docs/latest/#tag/Webhook) API.
     """
     _path = 'webhook'
-    _name = 'WEBHOOK'
+    _name = 'webhook'
 
     @classmethod
     def update(cls, entities):
