@@ -287,7 +287,7 @@ class Entity(dict):
         error if the requested link is not valid for this Entity type."""
         link_set = set()
         if links is not None:
-            if not isinstance(links, list):
+            if isinstance(links, str) or not hasattr(links, '__iter__'):
                 raise projectal.UsageException("Parameter 'links' must be a list or None.")
 
             defs = cls({})._link_def_by_name
@@ -859,6 +859,10 @@ class Entity(dict):
             if to_add:
                 changes['add'] = to_add
             return changes
+
+    @classmethod
+    def get_link_definitions(cls):
+        return cls({})._link_def_by_name
     # --- ---
 
     def entity_name(self):
